@@ -1,7 +1,7 @@
 package App::MediaInfo;
 
 our $DATE = '2019-06-09'; # DATE
-our $VERSION = '0.121'; # VERSION
+our $VERSION = '0.122'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,11 @@ use warnings;
 
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Utilities related to media files',
+};
+
 our %arg0_media_multiple = (
     media => {
         summary => 'Media files/URLs',
@@ -48,6 +53,15 @@ our %argopt_backend = (
     },
 );
 
+our %argopt_quiet = (
+    quiet => {
+        summary => "Don't output anything on command-line, ".
+            "just return appropriate exit code",
+        schema => 'true*',
+        cmdline_aliases => {q=>{}, silent=>{}},
+    },
+);
+
 $SPEC{media_info} = {
     v => 1.1,
     summary => 'Get information about media files/URLs',
@@ -97,7 +111,17 @@ _
     args => {
         %arg0_media_single,
         %argopt_backend,
+        %argopt_quiet,
     },
+    examples => [
+        {
+            summary => 'Move all portrait videos to portrait/',
+            src => 'for f in *.mp4;do [[prog]] -q "$f" && mv "$f" portrait/; done',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+    ],
 };
 sub media_is_portrait {
     my %args = @_;
@@ -113,8 +137,8 @@ sub media_is_portrait {
 
     [200, "OK", $is_portrait, {
         'cmdline.exit_code' => $is_portrait ? 0:1,
-        'cmdline.result' => '',
-        'cmdline.result.interactive' => "Media is ".
+        'cmdline.result' => $args{quiet} ? '' :
+            "Media is ".
             ($is_portrait ? "portrait" : "NOT portrait (landscape)"),
     }];
 }
@@ -131,7 +155,17 @@ _
     args => {
         %arg0_media_single,
         %argopt_backend,
+        %argopt_quiet,
     },
+    examples => [
+        {
+            summary => 'Convert all landscape mkv videos to mp4',
+            src => 'for f in *.mkv;do [[prog]] -q "$f" && ffmpeg -i "$f" "$f.mp4"; done',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+    ],
 };
 sub media_is_landscape {
     my %args = @_;
@@ -147,8 +181,8 @@ sub media_is_landscape {
 
     [200, "OK", $is_landscape, {
         'cmdline.exit_code' => $is_landscape ? 0:1,
-        'cmdline.result' => '',
-        'cmdline.result.interactive' => "Media is ".
+        'cmdline.result' => $args{quiet} ? '' :
+            "Media is ".
             ($is_landscape ? "landscape" : "NOT landscape (portrait)"),
     }];
 }
@@ -183,7 +217,7 @@ sub media_orientation {
 }
 
 1;
-# ABSTRACT: Return exit code 0 if media is portrait
+# ABSTRACT: Utilities related to media files
 
 __END__
 
@@ -193,11 +227,11 @@ __END__
 
 =head1 NAME
 
-App::MediaInfo - Return exit code 0 if media is portrait
+App::MediaInfo - Utilities related to media files
 
 =head1 VERSION
 
-This document describes version 0.121 of App::MediaInfo (from Perl distribution App-MediaInfo), released on 2019-06-09.
+This document describes version 0.122 of App::MediaInfo (from Perl distribution App-MediaInfo), released on 2019-06-09.
 
 =head1 FUNCTIONS
 
@@ -264,6 +298,10 @@ Choose a specific backend.
 
 Media file/URL.
 
+=item * B<quiet> => I<true>
+
+Don't output anything on command-line, just return appropriate exit code.
+
 =back
 
 Returns an enveloped result (an array).
@@ -304,6 +342,10 @@ Choose a specific backend.
 
 Media file/URL.
 
+=item * B<quiet> => I<true>
+
+Don't output anything on command-line, just return appropriate exit code.
+
 =back
 
 Returns an enveloped result (an array).
